/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.0
 *  Last Modified: 13 Abril 2010
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "edicion.h"
#include "ui_edicion.h"
#include <QMessageBox>

Edicion::Edicion(QTableView *t, QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Edicion)
{
    ui->setupUi(this);
    tableview = t;
    // Conecto las seales  de pulsar los botones con las acciones pertinentes
    connect(ui->pushButton,SIGNAL(clicked()),this,SLOT(editarEntrada()));
    connect(ui->pushButton_2,SIGNAL(clicked()),this,SLOT(hide()));
    marca_imp = "*";
    // Quitando los botones de maximizar y minimizar
    Qt::WindowFlags flags = Qt::Window | Qt::WindowCloseButtonHint;
    this->setWindowFlags(flags);
    // Hacemos la ventana unresizeable
    setMinimumSize(size());
    setMaximumSize(size());
    fila = 0;
}

Edicion::~Edicion()
{
    delete ui;
}

void Edicion::obtenerEntrada(int fila)
{
    QAbstractItemModel *modelo = tableview->model();
    QString nombre = "", telefono = "";
    bool importante = false;
    // Obtengo los datos
    QModelIndex indice = modelo->index(fila, 0, QModelIndex());
    nombre = modelo->data(indice, Qt::DisplayRole).toString();
    indice = modelo->index(fila, 1, QModelIndex());
    telefono = modelo->data(indice, Qt::DisplayRole).toString();
    indice = modelo->index(fila, 2, QModelIndex());
    importante = (modelo->data(indice, Qt::DisplayRole).toString().trimmed() == marca_imp );
    // Muestro los datos
    ui->lineEdit->setText(nombre);
    ui->lineEdit_2->setText(telefono);
    ui->checkBox->setChecked(importante);
    this->fila = fila;
}


void Edicion::editarEntrada()
{
    QString err;
    // Si no hay errores en los datos introducidos
    if( ! hayErrores(err) )
    {
    		// Modifico los datos de la linea seleccionada
        QAbstractItemModel *modelo = tableview->model();
        modelo->setData(modelo->index(fila, 0), ui->lineEdit->text()); // Nombre
        modelo->setData(modelo->index(fila, 1), ui->lineEdit_2->text()); // Telefono
        if( ui->checkBox->isChecked() ) // Importante o no
           modelo->setData(modelo->index(fila, 2), marca_imp);
        else
           modelo->setData(modelo->index(fila, 2), " ");
        // Ordeno la lista ascendentemente por nombre y escondo el dialogo
        tableview->sortByColumn(0,Qt::AscendingOrder);
        this->hide();
    }
    else // Si se ha cometido algun error, muestro un mensaje indicandolo
    {
        QMessageBox msgBox(QMessageBox::Warning,"Error al introducir los datos",err, 0, this);
        msgBox.addButton(tr("Aceptar"), QMessageBox::AcceptRole);
        msgBox.exec();
    }

}


bool Edicion::hayErrores(QString &err)
{
	// Compruebo, mediante expresiones regulares que los campos son correctos
    err = "";
    QRegExp rx("[0-9]+");
    if( ui->lineEdit->text().trimmed() == "" )  // nombre en blaco
        err += "- Nombre: No puede estar vaco\n";
    if( ui->lineEdit_2->text().trimmed() == "" ) // Telefono en blanco
        err += "- Telfono: No puede estar vaco\n";
        else if( !rx.exactMatch(ui->lineEdit_2->text().trimmed())) // Telefono contiene algo que no es un numero
            err += "- Telfono: Debe contener nicamente nmeros\n";
    return err != "";
}
