/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.0
 *  Last Modified: 13 Abril 2010
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "llamada_entrante.h"
#include "ui_llamada_entrante.h"
#include <QtGui>
#include <QDateTime>

Llamada_entrante::Llamada_entrante(QString dirpath, QWidget *parent) :
    QDialog(parent),
    path(dirpath),
    ui(new Ui::Llamada_entrante)
{
    ui->setupUi(this);
    // Creamos el dialogo de llamada saliente
    llam_sal = new Llamada_saliente(this);
    // Enlazamos los slots
    connect(ui->pushButton,SIGNAL(clicked()),this,SLOT(hide()));
    connect(ui->tableView,SIGNAL(doubleClicked(QModelIndex)),this,SLOT(llamar()));
    // Creamos el modelo e insertamos las columnas
    modelo = new QStandardItemModel(0, 3, this);
    modelo->setHeaderData(0, Qt::Horizontal, QObject::tr("Nombre"));
    modelo->setHeaderData(1, Qt::Horizontal, QObject::tr("Telfono"));
    modelo->setHeaderData(2, Qt::Horizontal, QObject::tr("Fecha"));
    // Ponemos los tamaos
    ui->tableView->setModel(modelo);
    ui->tableView->setColumnWidth(0,223);
    ui->tableView->setColumnWidth(1,108);
    ui->tableView->setColumnWidth(2,127);
    // Establecemos la ordenacion
    ui->tableView->setSortingEnabled(true);
    ui->tableView->sortByColumn(2,Qt::DescendingOrder);
    // Quitando los botones de maximizar y minimizar
    Qt::WindowFlags flags = Qt::Window | Qt::WindowCloseButtonHint;
    this->setWindowFlags(flags);
}

/* Aade una entrada al listado */
void Llamada_entrante::addEntrada(const QString &nombre,const QString &telefono, const bool &imp)
{
    // Creo una fila y la relleno
    QDateTime t = QDateTime::currentDateTime();
    modelo->insertRow(0);
    ui->tableView->setRowHeight(0,22);
    modelo->setData(modelo->index(0, 0), nombre);
    modelo->setData(modelo->index(0, 1), telefono);
    modelo->setData(modelo->index(0, 2), t.toString("dd/MM/yyyy hh:mm:ss"));
    // Destaco las importantes
    if( imp )
        for(int i=0; i<modelo->columnCount(); ++i)
        {
 //           modelo->setData(modelo->index(0, i), QColor(Qt::red), Qt::BackgroundColorRole);
            modelo->setData(modelo->index(0, i), QColor(Qt::red), Qt::ForegroundRole);
            // Reproduzco un pequeo ring
            if(QDir(path).exists("ring.wav"))
                QSound::play(path + "ring.wav");
        }

}

Llamada_entrante::~Llamada_entrante()
{
    delete ui;
}

/* Llamar al numero seleccionado */
void Llamada_entrante::llamar()
{
    // Obtenemos la fila y si hay alguna seleccionada
    int fila = this->filaSeleccionada();
    if( fila != -1)
    {
    	// Obtengo la informacion de la persona a la que queremos llamar
        QModelIndex indice = modelo->index(fila, 1, QModelIndex()),indice2 = modelo->index(fila, 0, QModelIndex());
        QVariant tel = modelo->data(indice, Qt::DisplayRole);
        QVariant nom = modelo->data(indice2, Qt::DisplayRole);
        // Genero la url y la lanzo
        url = QUrl(url_llamada + tel.toString());
        qnam.get(QNetworkRequest(url));
        // Muestro el dialog de llamada saliente con la informacion del contacto
        llam_sal->setText("Llamando a:\n" + nom.toString() + "\n" + tel.toString());
        llam_sal->show();
    }

}


/* Devuelve la fila selecionada de la tabla */
int Llamada_entrante::filaSeleccionada()
{
    // Obtenemos una lista de filas seleccionadas y devolvemos la primera
    QItemSelectionModel *selectionModel = ui->tableView->selectionModel();
    QModelIndexList indexes = selectionModel->selectedRows();
    QModelIndex index = indexes.first();
    // Devuelvo la primera fila seleccionada
    foreach (index, indexes) {
        return index.row();
    }
    return -1;
}
